==> mule-service-http-1.4.1-test-sources.jar: org/mule/service/http/impl/functional/client/RedirectHttpClientPostStreamingTestCase.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.service.http.impl.functional.client;

import static org.mule.runtime.http.api.HttpConstants.HttpStatus.OK;
import static org.mule.runtime.http.api.HttpConstants.HttpStatus.SEE_OTHER;
import static org.mule.runtime.http.api.HttpConstants.Method.POST;
import static org.mule.service.http.impl.AllureConstants.HttpFeature.HttpStory.STREAMING;

import java.io.ByteArrayInputStream;

import org.mule.runtime.http.api.client.HttpRequestOptions;
import org.mule.runtime.http.api.domain.entity.InputStreamHttpEntity;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;
import org.mule.runtime.http.api.domain.message.response.HttpResponse;
import org.mule.runtime.http.api.domain.message.response.HttpResponseBuilder;

import io.qameta.allure.Story;
import io.qameta.allure.junit4.DisplayName;

@Story(STREAMING)
@DisplayName("Validates that the POST body is preserved on redirect")
public class RedirectHttpClientPostStreamingTestCase extends HttpClientPostStreamingTestCase {

  public RedirectHttpClientPostStreamingTestCase(String serviceToLoad) {
    super(serviceToLoad);
  }

  public HttpResponse setUpHttpResponse(HttpRequest request) {
    HttpResponseBuilder response = HttpResponse.builder();
    if (request.getUri().getPath().equals("/first")) {
      return response.statusCode(SEE_OTHER.getStatusCode()).addHeader("Location", "/bla").build();
    } else {
      extractPayload(request);
      return response.statusCode(OK.getStatusCode()).build();
    }
  }

  @Override
  public HttpResponse doSetUpHttpResponse(HttpRequest request) {
    HttpResponseBuilder response = HttpResponse.builder();
    if (request.getUri().getPath().equals("/first")) {
      return response.statusCode(SEE_OTHER.getStatusCode()).addHeader("Location", "/bla").build();
    } else {
      extractPayload(request);
      return response.statusCode(OK.getStatusCode()).build();
    }
  }

  @Override
  public HttpRequestOptions getOptions() {
    return HttpRequestOptions.builder().responseTimeout(RESPONSE_TIMEOUT).build();
  }

  @Override
  public HttpRequest getRequest() {
    return HttpRequest.builder().method(POST).uri(getUri() + "/first")
        .entity(new InputStreamHttpEntity(new ByteArrayInputStream(TEST_PAYLOAD.getBytes()))).build();
  }

}

==> mule-service-http-1.6.25-20250709.011049-19-test-sources.jar: org/mule/service/http/impl/functional/client/RedirectHttpClientPostStreamingTestCase.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.service.http.impl.functional.client;

import static org.mule.runtime.http.api.HttpConstants.HttpStatus.OK;
import static org.mule.runtime.http.api.HttpConstants.HttpStatus.TEMPORARY_REDIRECT;
import static org.mule.runtime.http.api.HttpConstants.Method.POST;
import static org.mule.service.http.impl.AllureConstants.HttpFeature.HttpStory.STREAMING;

import java.io.ByteArrayInputStream;

import org.mule.runtime.http.api.client.HttpRequestOptions;
import org.mule.runtime.http.api.domain.entity.InputStreamHttpEntity;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;
import org.mule.runtime.http.api.domain.message.response.HttpResponse;
import org.mule.runtime.http.api.domain.message.response.HttpResponseBuilder;

import io.qameta.allure.Story;
import io.qameta.allure.junit4.DisplayName;

@Story(STREAMING)
@DisplayName("Validates that the POST body is preserved on redirect")
public class RedirectHttpClientPostStreamingTestCase extends HttpClientPostStreamingTestCase {

  public RedirectHttpClientPostStreamingTestCase(String serviceToLoad) {
    super(serviceToLoad);
  }

  public HttpResponse setUpHttpResponse(HttpRequest request) {
    HttpResponseBuilder response = HttpResponse.builder();
    if (request.getUri().getPath().equals("/first")) {
      return response.statusCode(TEMPORARY_REDIRECT.getStatusCode()).addHeader("Location", "/bla").build();
    } else {
      extractPayload(request);
      return response.statusCode(OK.getStatusCode()).build();
    }
  }

  @Override
  public HttpResponse doSetUpHttpResponse(HttpRequest request) {
    HttpResponseBuilder response = HttpResponse.builder();
    if (request.getUri().getPath().equals("/first")) {
      return response.statusCode(TEMPORARY_REDIRECT.getStatusCode()).addHeader("Location", "/bla").build();
    } else {
      extractPayload(request);
      return response.statusCode(OK.getStatusCode()).build();
    }
  }

  @Override
  public HttpRequestOptions getOptions() {
    return HttpRequestOptions.builder().responseTimeout(RESPONSE_TIMEOUT).build();
  }

  @Override
  public HttpRequest getRequest() {
    return HttpRequest.builder().method(POST).uri(getUri() + "/first")
        .entity(new InputStreamHttpEntity(new ByteArrayInputStream(TEST_PAYLOAD.getBytes()))).build();
  }

}
